* Title : Growth, Pollution, and Life Expectancy: China from 1991-2012
* Author: Ebenstein, Fan, Greenstone, He, Yin, Zhou     

#delimit ; 

*======================================================================================================================================================;
* SECTION 1 BREAK SECTION 1 BREAK SECTION 1 BREAK SECTION 1 BREAK SECTION 1 BREAK SECTION 1 BREAK  SECTION 1 BREAK  SECTION 1 BREAK  SECTION 1 BREAK   ;
*======================================================================================================================================================;
*** Abridged life tables for all causes of death combined for the total population: 161 DSPS points, 2004-2012 ; 
*** Following the standard method in Newell, Colin. Methods and models in demography. Guilford Press, 1990 ; 

forvalues k=1/1 { ;    * Disease categories ;     
	
	forvalues j=0/2 { ;  * Gender ; 
	
		use DSP_04_12_workingfile_wide.dta, clear ; 
		
		if `k'==1 { ;  keep if gbdcode=="U000" ;  } ;   * All deaths is used to calculate life expectancy ; 
		
		if `j'==0 { ;  di "Both gender" ; collapse (sum) dtotal-d85 (mean)total-t85, by(year code) ;   	} ;   
		if `j'==1 { ;  di "Male" ;        keep if gender==1 ;  keep dtotal-d85 mtotal-m85 year code ;  	} ; 
		if `j'==2 { ;  di "Female" ;      keep if gender==2 ;  keep dtotal-d85 ftotal-f85 year code ;  	} ; 
		
		ren dtotal d100 ;   foreach i in 0 1 5 10 15 20 25 30 35 40 45 50 55 60 65 70 75 80 85 { ; cap ren m`i' t`i' ; cap ren f`i' t`i' ; } ;  
		cap ren total t100 ;  cap ren ftotal t100 ;  cap ren mtotal t100 ;       * 100 as the last category for all age_group(0-85+) for total deaths ; 
		
		gen a =code*10000+year ; 
		format a %9.0fc;
		reshape long d t, i(a) j(age_group) ; 
		sort a age_group ; bysort a: gen b=_n ; bysort a: gen c=-(_n-20) ;  replace c=20 if c==0 ;  tsset a b ;  tab b age_group ; 
		
		/*
		*** Test codes using a known life table ; 
		use testdata.dta, clear ; 
		gen a=1 ; gen b=_n ; gen c=-(_n-20) ; tsset a b ;
		*** Notes: codes are correct ; 
		*/ ; 
		
		gen nMx=d/t ;  * t is treated as mid year population ; 
		gen nax=0.5 ;  replace nax=0.1 if age_group==0 ;   replace nax=0.4 if age_group==1 ;  * note, nax can also be estimated using iteration methods ; 
		gen n=5 ;      replace n=1 if age_group==0 ;       replace n=4 if age_group==1 ;         
		/* gen nqx = n*nMx/(1+(n-nax)*nMx) ;   replace nqx=1 if age_group==85 ;   * when nax is the average number of years of dead people lived in the time interval ;  */ ; 
		gen nqx = n*nMx/(1+n*(1-nax)*nMx) ;   replace nqx=1 if age_group==85 ;   * when nax is the a percentage time of dead people lived in the time interval ; 
		gen npx = 1-nqx ;
		gen lx=100000 ;  forvalues i=2/`=_N' { ;  if b[`i']~=1 { ; quiet replace lx=L.lx*L.npx in `i' ; } ;   } ; 
		gen ndx=lx-F.lx ; 
		gen nLx=n*F.lx+nax*ndx ;   replace nLx=lx/nMx if age_group==85 ; * open end group ; 
		tsset a c ; sort a c ; 
		gen Tx=nLx ;   forvalues i=2/`=_N' { ;  if c[`i']~=1 { ; quiet replace Tx=Tx+L.Tx in `i' ; } ;   } ; 
		gen ex = Tx/lx ; 
		sort a b ; 
			
		gen gender = `j' ;   		
		gen cause=`k' ;     		
			
		saveold temp`k'_`j'.dta, replace ; 

	} ;  
} ; 



*======================================================================================================================================================;
* SECTION 2 BREAK SECTION 2 BREAK SECTION 2 BREAK SECTION 2 BREAK SECTION 2 BREAK SECTION 2 BREAK  SECTION 2 BREAK  SECTION 2 BREAK  SECTION 2 BREAK   ;
*======================================================================================================================================================;
*** Abridged life tables for all causes of death eliminating specified causes, 161 DSPS points, 2004-2012 ; 
*** http://www.cdc.gov/nchs/data/lifetables/life89_1_4.pdf, file is also in dropbox ; 
*** "i" prefix to indicate variables eliminating death cause "i" ; 

forvalues k=2/4 { ;    * disease categories, k=1 is in section 1 ; 
	
	forvalues j=0/2 { ;  * gender ; 
	
		use DSP_04_12_workingfile_wide.dta, clear ; 

		if `k'==2 { ; 	keep if gbdcode=="U038" | gbdcode=="U067" | gbdcode=="U111" ; 			                  collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==3 { ; 	keep if gbdcode=="U104" ; 		} ; 
		if `k'==4 { ; 	keep if gbdcode=="U104" | gbdcode=="U038" | gbdcode=="U067" | gbdcode=="U111" ; 			collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		
		if `j'==0 { ; 	di "Both gender" ; collapse (sum) dtotal-d85 (mean)total-t85, by(year code) ;    	} ;   
		if `j'==1 { ; 	di "Male" ;        keep if gender==1 ;  keep dtotal-d85 mtotal-m85 year code ;   	} ; 
		if `j'==2 { ; 	di "Female" ;      keep if gender==2 ;  keep dtotal-d85 ftotal-f85 year code ;   	} ; 
		
		ren dtotal d100 ;   foreach i in 0 1 5 10 15 20 25 30 35 40 45 50 55 60 65 70 75 80 85 { ; cap ren m`i' t`i' ; cap ren f`i' t`i' ; } ;  
		cap ren total t100 ;  cap ren ftotal t100 ;  cap ren mtotal t100 ; 
		
		gen a =code*10000+year ; 
		reshape long d t, i(a) j(age_group) ; 
		keep year code age_group d ;  ren d id ; 

		if `j'==0 { ;  		merge 1:1 year code age_group using temp1_0.dta ;  drop _merge ;   } ;   
		if `j'==1 { ;  		merge 1:1 year code age_group using temp1_1.dta ;  drop _merge ;   } ; 
		if `j'==2 { ;  		merge 1:1 year code age_group using temp1_2.dta ;  drop _merge ;   } ; 

		gen inrx = id/d ;   * The proportion of the deaths recorded in the age interval x to x+n attributable to the ith cause of death adjusted for not-stated age, no non-stated ages ; 
		gen inpx = npx^(1-inrx) ;      replace inpx=1 if inpx==. & age_group <=85 ;   * when no death in this age category ;   
		gen inqx = 1- inpx ; 	
	
		sort a age_group ;   tsset a b ;   tab b age_group ;   order a b c ; 	

		/*
		*** Test codes using a known life table ; 
		use testdata2.dta, clear ; 
		gen a=1 ; gen b=_n ; gen c=-(_n-22) ; tsset a b ;
		gen inrx=(nqx-inqx)/nqx ; 		gen inpx=1-inqx
		*** Notes: not able to replicate the table in the NVSS report exactly (lack of raw mortality data), but the life expentancies are very similar expecially for the young cohorts ; 
		*/ ; 

		gen ilx=100000 ;  forvalues i=2/`=_N' { ;  if b[`i']~=1 { ; quiet replace ilx=L.ilx*L.inpx in `i' ; } ;   } ; 
		gen indx=ilx-F.ilx ; 
		gen nfx=(n*lx-nLx)/(lx-F.lx) ; 
		gen inLx=(n-nfx)*ilx + nfx*F.ilx ;   replace inLx=ex*ilx/(1-inrx) if age_group==85 ;  * open end group ; 
		tsset a c ; sort a c ; 
		gen iTx=inLx ;   forvalues i=2/`=_N' { ;  if c[`i']~=1 { ; quiet replace iTx=iTx+L.iTx in `i' ; } ;   } ; 
		gen iex = iTx/ilx ; 
		sort a b ; 
		
		drop gender cause ; 			
		gen gender = `j' ;   		
		gen cause=`k' ;     		
				
		saveold temp`k'_`j'.dta, replace ; 

	} ;  
} ; 



***========================================================================================================; 
*** Creat life table ; 

use temp1_0.dta, clear ; append using temp1_1.dta ;  append using temp1_2.dta ; 
forvalues k=2/4 { ;   forvalues j=0/2 { ;  append using temp`k'_`j'.dta ; 	} ;  } ; 

label define genderlbl 0 "Both" 1 "Male" 2 "Female" ;                                    
label define causelbl 1 "All Diseases" 2 "Eliminating Lung-related Diseases" 3 "Elimination Cadio-related Diseases"  4 "Elimination Cardiorespiratory-related Diseases";    
label value gender genderlbl ;    
label value cause causelbl ;  

drop a b c ; 
order year code gender age_group cause ;
sort year code gender cause age_group ;   

keep year code gender cause age_group d t nqx lx nLx ex id inqx ilx inLx iex ; 

label var cause "Causes of death" ; 
label var d     "Number of death" ;  
label var t     "Population" ; 
label var nqx   "Probablity of dying between age x and x+n" ;  
label var lx    "Number surviving to age x" ; 
label var nLx   "Person-year lived between age x and x+n" ; 
label var ex    "Expectation of life at age x" ; 
label var id    "Number of death from cause i" ;  
label var inqx  "Probablity of dying between age x and x+n eliminating death cause i" ;  
label var ilx   "Number surviving to age x eliminating death cause i" ; 
label var inLx  "Person-year lived between age x and x+n eliminating death cause i" ; 
label var iex   "Expectation of life at age x eliminating death cause i" ; 

*** Below I keep life expectancy for all age groups ; 

	preserve ; 
	keep if cause==1 ;    * life expectancy for all age groups ; 
	keep year age_group code gender ex ; 
	drop if age_group==100 ; 
	label var ex  "Life expectancy" ; 
	sort code gender year age_group ; 
	saveold LifeTable_AllAges_04_12.dta, replace ; 
	restore ; 

*** Below I keep life expectancy for new born only ; 

	keep if age_group==0 & cause==1 ; * life expectancy at birth for all causes of death ; 
	keep year code gender ex ; 
	label var ex  "Expectation of life at birth" ;  
	saveold LifeTable_04_12.dta, replace ; 

forvalues k=1/4 { ;    forvalues j=0/2 { ;  	erase temp`k'_`j'.dta ; 	 } ; } ; 


*======================================================================================================================================================;
* SECTION 3 BREAK SECTION 3 BREAK SECTION 3 BREAK SECTION 3 BREAK SECTION 3 BREAK SECTION 3 BREAK  SECTION 3 BREAK  SECTION 3 BREAK  SECTION 3 BREAK   ;
*======================================================================================================================================================;
*** Age adjusted mortality rates for each year and each DSPS point: death per 100000 people ; 
*** For AER papers and proceedings, try to look at the following disease categories  ; 

forvalues k=1/22 { ;    
	forvalues j=0/2 { ;  	
		use DSP_04_12_workingfile_wide.dta, clear ; 
		
		if `k'==1 { ;   keep if gbdcode=="U000" ;  } ;                                                        * already year code gender, don't need to collapse ; 
		if `k'==2 { ; 	keep if gbdcode=="U038" | gbdcode=="U067" | gbdcode=="U111" ; 			                  collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==3 { ; 	keep if gbdcode=="U104" ;  } ;                                                        * already year code gender, don't need to collapse ; 
		if `k'==4 { ; 	keep if gbdcode=="U104" | gbdcode=="U067" | gbdcode=="U111" ; 		                    collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==5 { ; 	keep if gbdcode=="U104" | gbdcode=="U108"; 
										foreach var of varlist dtotal-d85 { ; 	replace `var'=-`var' if gbdcode=="U108" ; } ; collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==6 { ; 	keep if gbdcode=="U060" | gbdcode=="U067" ;  
		                foreach var of varlist dtotal-d85 { ; 	
											replace `var'=-`var' if gbdcode=="U067" ; } ;                                       collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==7 { ; 	keep if gbdcode=="U108" ;  } ; 	                                                      * already year code gender, don't need to collapse ; 
		if `k'==8 { ; 	keep if gbdcode=="U148" | gbdcode=="U156" ; 	
		                foreach var of varlist dtotal-d85 { ; 	replace `var'=-`var' if gbdcode=="U156" ; } ; collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==9 { ; 	keep if gbdcode=="U067" | gbdcode=="U111" ; 			                                    collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==10 { ; 	keep if gbdcode=="U000" | gbdcode=="U104" | gbdcode=="U067" | gbdcode=="U111" ; 	    
										foreach var of varlist dtotal-d85 { ; 	
											replace `var'=-`var' if gbdcode=="U104" | gbdcode=="U067" | gbdcode=="U111" ; } ;   collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==11 { ; 	keep if gbdcode=="U148"  ; 	} ;                                                       * already year code gender, don't need to collapse ; 
		if `k'==12 { ; 	keep if gbdcode=="U038"  ; 	} ;                                                       * already year code gender, don't need to collapse ; 
		if `k'==13 { ; 	keep if gbdcode=="U067"  ; 	} ;                                                       * already year code gender, don't need to collapse ; 
		if `k'==14 { ; 	keep if gbdcode=="U104" | gbdcode=="U067" ;                                           collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==15 { ; 	keep if gbdcode=="U000" | gbdcode=="U104" | gbdcode=="U067" ;                         
		                foreach var of varlist dtotal-d85 { ; 	
											replace `var'=-`var' if gbdcode=="U104" | gbdcode=="U067" ; } ;                     collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==16 { ; 	keep if gbdcode=="U000" | gbdcode=="U104" | gbdcode=="U060" | gbdcode=="U038" | gbdcode=="U148" ;                         
		                foreach var of varlist dtotal-d85 { ; 	
											replace `var'=-`var' if gbdcode=="U104" | gbdcode=="U060" | gbdcode=="U038" | gbdcode=="U148" ; } ;      collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==17 { ; 	keep if gbdcode=="U112"  ; 	} ;                                                       * already year code gender, don't need to collapse ; 
		if `k'==18 { ; 	keep if gbdcode=="U000" | gbdcode=="U104" | gbdcode=="U060" | gbdcode=="U112" | gbdcode=="U148" ;                         
		                foreach var of varlist dtotal-d85 { ; 	
											replace `var'=-`var' if gbdcode=="U104" | gbdcode=="U060" | gbdcode=="U112" | gbdcode=="U148" ; } ;      collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==19 { ; 	keep if gbdcode=="U111"  ; 	} ;                                                       * already year code gender, don't need to collapse ; 
		if `k'==20 { ; 	keep if gbdcode=="U104" | gbdcode=="U067" | gbdcode=="U114" ;                         collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==21 { ; 	keep if gbdcode=="U000" | gbdcode=="U104" | gbdcode=="U060" | gbdcode=="U111" | gbdcode=="U148" | gbdcode=="U038" ;                         
		                foreach var of varlist dtotal-d85 { ; 	
											replace `var'=-`var' if gbdcode=="U104" | gbdcode=="U060" | gbdcode=="U111" | gbdcode=="U148" | gbdcode=="U038" ; } ;      collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==22 { ; 	keep if gbdcode=="U000" | gbdcode=="U104" | gbdcode=="U060" | gbdcode=="U111" | gbdcode=="U148" ;                         
		                foreach var of varlist dtotal-d85 { ; 	
											replace `var'=-`var' if gbdcode=="U104" | gbdcode=="U060" | gbdcode=="U111" | gbdcode=="U148" ; } ;      collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  

		if `j'==0 { ; 	di "Both gender" ; collapse (sum) dtotal-d85 (mean)total-t85, by(year code) ;    	} ;   
		if `j'==1 { ; 	di "Male" ;        keep if gender==1 ;  keep dtotal-d85 mtotal-m85 year code ;   	} ; 
		if `j'==2 { ; 	di "Female" ;      keep if gender==2 ;  keep dtotal-d85 ftotal-f85 year code ;   	} ; 

		ren dtotal d100 ;   foreach i in 0 1 5 10 15 20 25 30 35 40 45 50 55 60 65 70 75 80 85 { ; cap ren m`i' t`i' ; cap ren f`i' t`i' ; } ;  
		cap ren total t100 ;  cap ren ftotal t100 ;  cap ren mtotal t100 ;
		
		gen a =code*10000+year ;   drop if a==. ; 
		reshape long d t, i(a) j(age_group) ; 
		
		merge m:1 age_group using C:\Dropbox\China_Pollution_Projects\rawfiles\pop_weights_long.dta ; drop _merge ;   * Weights are from China's 2000 census ; 
		
		gen dr = 100000*d/t ;    * age specific death rate per 100k ; 
		
		* prepare for calculating age adjusted death rate per 100k ; 
		if `j'==0 { ; 	gen ajdr = pweight*dr ; } ;   
		if `j'==1 { ; 	gen ajdr = mweight*dr ; } ; 
		if `j'==2 { ; 	gen ajdr = fweight*dr ; } ; 

		gen gender = `j' ;   		 
		gen cause=`k' ;     		 		
		saveold temp`k'_`j'.dta, replace ; 
	} ; 
} ; 

*** Merge life expectancy with mortality rate ;   

use temp1_0.dta, clear ; append using temp1_1.dta ;  append using temp1_2.dta ;       
forvalues k=2/22 { ;   forvalues j=0/2 { ;  append using temp`k'_`j'.dta ; 	} ;  } ;  

drop a pweight fweight mweight ;  
label define genderlbl 0 "Both" 1 "Male" 2 "Female" ;                                    
label define causelbl 1 "All Diseases" 2 "Lung-related Diseases" 3 "Cadio-related Diseases"  4 "Cardiorespiratory-related Diseases" 5 "Heart Disease" 6 "Cancer" 7 "Stroke" 8 "Unintentional Injury" 9 "Non-communicable lung diseases" 10 "Non-pollution related diseases" 11 "Injury" 12 "Communicable lung diseases" 13 "Lung cancer" ;    
label value gender genderlbl ;    label value cause causelbl ;  
label var cause "Cause of death" ; 
*label var d "Number of death" ;  
*label var t "Population" ; 
label var dr   "Coarse death rate per 100k people" ; 
label var ajdr "Age adjusted death rate per 100k people" ; 

order year code gender age_group cause ;
sort year code gender cause age_group ;  

preserve ; 
	
	*** Calculate the age adjusted death rate and life expectancy at birth ; 
	
	* Create age ajusted mortality rate per 100k ; 
	bysort year code gender cause: egen a = sum(ajdr) ;  replace ajdr=a if age_group==100 ; 
	keep if age_group==100 ; 
	
	ren d death ;  ren t pop ; 
	keep year code gender cause death pop dr ajdr ; 
	gen b=code*100000+10*year+gender ; 
	reshape wide death pop dr ajdr, i(b) j(cause) ; 
	drop pop2 pop3 pop4 pop5 pop6 pop7 pop8 pop9 pop10 pop11 pop12 pop13 pop14 pop15 pop16 pop17 pop18 pop19 pop20 pop21 pop22 b ;  
	ren pop1 population ; 

	saveold MortalityRate_04_12.dta, replace ;      
	
	merge 1:1 year code gender using LifeTable_04_12.dta ;  drop _merge ; 
	merge m:1 code using 161DSPS.dta ;  drop _merge ; 
	ren gender sex ; 
	sort code year sex ; 
	order overall_sequ code year sex population ; 
	
	saveold LifeTable_04_12.dta, replace ; 

restore ; 


*======================================================================================================================================================;
*** The same as the first half of section 3, but now keep every age group ; 

	drop if age_group==100 ; 
	ren d death ;  ren t pop ; 
	keep year code gender age_group cause death pop dr ;  * no need for ajdr for single age group  ; 
	gen b=code*10000000+1000*year+100*gender+age_group ; 
	reshape wide death pop dr, i(b) j(cause) ; 
	drop pop2 pop3 pop4 pop5 pop6 pop7 pop8 pop9 pop10 pop11 pop12 pop13 pop14 pop15 pop16 pop17 pop18 pop19 pop20 pop21 pop22 b ;  
	ren pop1 population ; 
	
	saveold MortalityRate_AllAges_04_12.dta, replace ;      
	
	merge 1:1 year code gender age_group using LifeTable_AllAges_04_12.dta ;  drop _merge ; 
	merge m:1 code using 161DSPS.dta ;  drop _merge ; 
	ren gender sex ; 
	sort code year sex age_group ; 
	order overall_sequ code year sex age_group population ; 

	saveold LifeTable_AllAges_04_12.dta, replace ; 

forvalues k=1/22 { ;    forvalues j=0/2 { ;  	erase temp`k'_`j'.dta ; 	cap erase t_`k'_`j'.dta ;  } ; } ; 

*======================================================================================================================================================;
* SECTION 4 BREAK SECTION 4 BREAK SECTION 4 BREAK SECTION 4 BREAK SECTION 4 BREAK SECTION 4 BREAK  SECTION 4 BREAK  SECTION 4 BREAK  SECTION 4 BREAK   ;
*======================================================================================================================================================;
*** Do 91-00 data following exactly the above procedure for 04-12 ; 
*** Abridged life tables for all causes of death combined for the total population: 145 DSPS points, 1991-2000 ; 
	
forvalues k=1/1 { ;    
	forvalues j=0/2 { ;  
	
		use DSP_91_00_workingfile_wide.dta, clear ; 
		
		if `k'==1 { ; keep if gbdcode==000 ;  } ;   * All diseases ; 
		
		if `j'==0 { ;  		di "Both gender" ;   keep if gender==0 ;  keep dtotal-d85 total-t85 year code ;   	} ;  * different from above code ;  
		if `j'==1 { ;  		di "Male" ;          keep if gender==1 ;  keep dtotal-d85 mtotal-m85 year code ;  	} ; 
		if `j'==2 { ;  		di "Female" ;        keep if gender==2 ;  keep dtotal-d85 ftotal-f85 year code ;  	} ; 
		
		ren dtotal d100 ;   foreach i in 0 1 5 10 15 20 25 30 35 40 45 50 55 60 65 70 75 80 85 { ; cap ren m`i' t`i' ; cap ren f`i' t`i' ; } ;  
		cap ren total t100 ;  cap ren ftotal t100 ;  cap ren mtotal t100 ;
		
		gen a =code*10000+year ; 
		reshape long d t, i(a) j(age_group) ; 
		sort a age_group ; bysort a: gen b=_n ; bysort a: gen c=-(_n-20) ;  replace c=20 if c==0 ;  tsset a b ;  tab b age_group ; 
		
		/*
		*** Test codes using a known life table ; 
		use testdata.dta, clear ; 
		gen a=1 ; gen b=_n ; gen c=-(_n-20) ; tsset a b ;
		*** Notes: codes are correct ; 
		*/ ; 
		
		gen nMx=d/t ;  * t is treated as mid year population ; 
		gen nax=0.5 ;  replace nax=0.1 if age_group==0 ;   replace nax=0.4 if age_group==1 ;  * note, nax can also be estimated using iteration methods ; 
		gen n=5 ;      replace n=1 if age_group==0 ;       replace n=4 if age_group==1 ;         
		/* gen nqx = n*nMx/(1+(n-nax)*nMx) ;   replace nqx=1 if age_group==85 ;   * when nax is the average number of years of dead people lived in the time interval ;  */ ; 
		gen nqx = n*nMx/(1+n*(1-nax)*nMx) ;   replace nqx=1 if age_group==85 ;   * when nax is the a percentage time of dead people lived in the time interval ; 
		gen npx = 1-nqx ;
		gen lx=100000 ;  forvalues i=2/`=_N' { ;  if b[`i']~=1 { ; quiet replace lx=L.lx*L.npx in `i' ; } ;   } ; 
		gen ndx=lx-F.lx ; 
		gen nLx=n*F.lx+nax*ndx ;   replace nLx=lx/nMx if age_group==85 ; * open end group ; 
		tsset a c ; sort a c ; 
		gen Tx=nLx ;   forvalues i=2/`=_N' { ;  if c[`i']~=1 { ; quiet replace Tx=Tx+L.Tx in `i' ; } ;   } ; 
		gen ex = Tx/lx ; 
		sort a b ; 
			
		gen gender = `j' ;   		
		gen cause=`k' ;     		
			
		saveold temp`k'_`j'.dta, replace ; 
	} ;  
} ; 


*======================================================================================================================================================;
*** Abridged life tables for all causes of death eliminating specified causes, 145 DSPS points, 1991-2000 ; 
*** http://www.cdc.gov/nchs/data/lifetables/life89_1_4.pdf, file is also in dropbox ; 
*** i prefix to indicate variables eliminating cause i ; 

forvalues k=2/4 { ;    * disease categories ; 
	
	forvalues j=0/2 { ;  * gender ; 
	
		use DSP_91_00_workingfile_wide.dta, clear ; 
		
		if `k'==2 { ; 	keep if gbdcode==038 | gbdcode==067 | gbdcode==111 ; 			collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==3 { ; 	keep if gbdcode==104 ; 		} ; 
		if `k'==4 { ; 	keep if gbdcode==104 | gbdcode==038 | gbdcode==067 | gbdcode==111 ; 			collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		
		if `j'==0 { ;  	di "Both gender" ;   keep if gender==0 ;  keep dtotal-d85 total-t85 year code ;   	} ;   
		if `j'==1 { ; 	di "Male" ;        keep if gender==1 ;  keep dtotal-d85 mtotal-m85 year code ;   	} ; 
		if `j'==2 { ; 	di "Female" ;      keep if gender==2 ;  keep dtotal-d85 ftotal-f85 year code ;   	} ; 
		
		ren dtotal d100 ;   foreach i in 0 1 5 10 15 20 25 30 35 40 45 50 55 60 65 70 75 80 85 { ; cap ren m`i' t`i' ; cap ren f`i' t`i' ; } ;  
		cap ren total t100 ;  cap ren ftotal t100 ;  cap ren mtotal t100 ;
		
		gen a =code*10000+year ; 
		reshape long d t, i(a) j(age_group) ; 
		keep year code age_group d ;  ren d id ; 
		
		if `j'==0 { ;  		merge 1:1 year code age_group using temp1_0.dta ;  drop _merge ;   } ;   
		if `j'==1 { ;  		merge 1:1 year code age_group using temp1_1.dta ;  drop _merge ;   } ; 
		if `j'==2 { ;  		merge 1:1 year code age_group using temp1_2.dta ;  drop _merge ;   } ; 

		gen inrx = id/d ;   * The proportion of the deaths recorded in the age interval x to x+n attributable to the ith cause of death adjusted for not-stated age, no non-stated ages ; 
		gen inpx = npx^(1-inrx) ;      replace inpx=1 if inpx==. & age_group <=85 ;   * when no death in this age category ;   
		gen inqx = 1- inpx ; 	
	
		sort a age_group ;   tsset a b ;   tab b age_group ;   order a b c ; 	

		/*
		*** Test codes using a known life table ; 
		use testdata2.dta, clear ; 
		gen a=1 ; gen b=_n ; gen c=-(_n-22) ; tsset a b ;
		gen inrx=(nqx-inqx)/nqx ; 		gen inpx=1-inqx
		*** Notes: not able to replicate the table in the NVSS report exactly (lack of raw mortality data), but the life expentancies are very similar expecially for the young cohorts ; 
		*/ ; 

		gen ilx=100000 ;  forvalues i=2/`=_N' { ;  if b[`i']~=1 { ; quiet replace ilx=L.ilx*L.inpx in `i' ; } ;   } ; 
		gen indx=ilx-F.ilx ; 
		gen nfx=(n*lx-nLx)/(lx-F.lx) ; 
		gen inLx=(n-nfx)*ilx + nfx*F.ilx ;   replace inLx=ex*ilx/(1-inrx) if age_group==85 ;  * open end group ; 
		tsset a c ; sort a c ; 
		gen iTx=inLx ;   forvalues i=2/`=_N' { ;  if c[`i']~=1 { ; quiet replace iTx=iTx+L.iTx in `i' ; } ;   } ; 
		gen iex = iTx/ilx ; 
		sort a b ; 
		
		drop gender cause ; 			
		gen gender = `j' ;   		
		gen cause=`k' ;     		
				
		saveold temp`k'_`j'.dta, replace ; 

	} ;  
} ; 

use temp1_0.dta, clear ; append using temp1_1.dta ;  append using temp1_2.dta ; 
forvalues k=2/4 { ;   forvalues j=0/2 { ;  append using temp`k'_`j'.dta ; 	} ;  } ; 

label define genderlbl 0 "Both" 1 "Male" 2 "Female" ;                                    
label define causelbl 1 "All Diseases" 2 "Eliminating Lung-related Diseases" 3 "Elimination Cadio-related Diseases"  4 "Elimination Cardiorespiratory-related Diseases";    
label value gender genderlbl ;    
label value cause causelbl ;  

drop a b c ; 
order year code gender age_group cause ;
sort year code gender cause age_group ;   

keep year code gender cause age_group d t nqx lx nLx ex id inqx ilx inLx iex ; 

label var cause "Causes of death" ; 
label var d "Number of death" ;  
label var t "Population" ; 
label var nqx "Probablity of dying between age x and x+n" ;  
label var lx  "Number surviving to age x" ; 
label var nLx "Person-year lived between age x and x+n" ; 
label var ex  "Expectation of life at age x" ; 
label var id   "Number of death from cause i" ;  
label var inqx "Probablity of dying between age x and x+n eliminating death cause i" ;  
label var ilx  "Number surviving to age x eliminating death cause i" ; 
label var inLx "Person-year lived between age x and x+n eliminating death cause i" ; 
label var iex  "Expectation of life at age x eliminating death cause i" ; 

order year code gender age_group cause ;
sort year code gender cause age_group ; 

*** Below I keep life expectancy for all age groups ; 
	preserve ; 
	keep if cause==1 ; 
	keep year age_group code gender ex ; 
	drop if age_group==100 ; 
	label var ex  "Life expectancy" ; 
	sort code gender year age_group ; 
	saveold LifeTable_AllAges_91_00.dta, replace ; 
	restore ; 

*** Below I keep life expectancy for new born only ; 

	keep if age_group==0 & cause==1 ; 
	keep year code gender ex ; 
	label var ex  "Expectation of life at birth" ;  
	saveold LifeTable_91_00.dta, replace ; 
	
forvalues k=1/4 { ;    forvalues j=0/2 { ;  	erase temp`k'_`j'.dta ; 	 } ; } ; 


*======================================================================================================================================================;
*** Age adjusted mortality rates for each year and each DSPS point: death per 100000 people ; 
*** For AER papers and proceedings, try to look at the following disease categories  ; 

forvalues k=1/22 { ;    * disease categories ; 
	
	forvalues j=0/2 { ;  * gender ; 
	
		use DSP_91_00_workingfile_wide.dta, clear ; 
		
		if `k'==1 { ;   keep if gbdcode==000 ;  } ;                                                        * already year code gender, don't need to collapse ; 
		if `k'==2 { ; 	keep if gbdcode==038 | gbdcode==067 | gbdcode==111 ; 			                         collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==3 { ; 	keep if gbdcode==104 ;  } ;                                                        * already year code gender, don't need to collapse ; 
		if `k'==4 { ; 	keep if gbdcode==104 | gbdcode==067 | gbdcode==111 ; 		                           collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==5 { ; 	keep if gbdcode==104 | gbdcode==108; 
										foreach var of varlist dtotal-d85 { ; 	replace `var'=-`var' if gbdcode==108 ; } ; collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==6 { ; 	keep if gbdcode==060 | gbdcode==067 ;  
		                foreach var of varlist dtotal-d85 { ; 	
											replace `var'=-`var' if gbdcode==067 ; } ;                                       collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==7 { ; 	keep if gbdcode==108 ; 	} ; 	                                                     * already year code gender, don't need to collapse ; 
		if `k'==8 { ; 	keep if gbdcode==148 | gbdcode==156 ; 	
		                foreach var of varlist dtotal-d85 { ; 	replace `var'=-`var' if gbdcode==156 ; } ; collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==9 { ; 	keep if gbdcode==067 | gbdcode==111 ; 			                                       collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==10 { ; 	keep if gbdcode==000 | gbdcode==104 | gbdcode==067 | gbdcode==111 ; 	    
										foreach var of varlist dtotal-d85 { ; 	
											replace `var'=-`var' if gbdcode==104 | gbdcode==067 | gbdcode==111 ; } ;         collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==11 { ; 	keep if gbdcode==148  ; } ;                                                        * already year code gender, don't need to collapse ; 
		if `k'==12 { ; 	keep if gbdcode==038  ; } ;                                                        * already year code gender, don't need to collapse ; 
		if `k'==13 { ; 	keep if gbdcode==067  ; } ;                                                        * already year code gender, don't need to collapse ; 
		if `k'==14 { ; 	keep if gbdcode==104 | gbdcode==067 ;                                              collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==15 { ; 	keep if gbdcode==000 | gbdcode==104 | gbdcode==067 ;                         
	                foreach var of varlist dtotal-d85 { ; 	
										replace `var'=-`var' if gbdcode==104 | gbdcode==067 ; } ;                          collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==16 { ; 	keep if gbdcode==000 | gbdcode==104 | gbdcode==060 | gbdcode==038 | gbdcode==148 ;                         
		                foreach var of varlist dtotal-d85 { ; 	
											replace `var'=-`var' if gbdcode==104 | gbdcode==060 | gbdcode==038 | gbdcode==148 ; } ;      collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==17 { ; 	keep if gbdcode==112  ; 	} ;                                                       * already year code gender, don't need to collapse ; 
		if `k'==18 { ; 	keep if gbdcode==000 | gbdcode==104 | gbdcode==060 | gbdcode==112 | gbdcode==148 ;                         
		                foreach var of varlist dtotal-d85 { ; 	
											replace `var'=-`var' if gbdcode==104 | gbdcode==060 | gbdcode==112 | gbdcode==148 ; } ;      collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==19 { ; 	keep if gbdcode==111  ; 	} ;                                                       * already year code gender, don't need to collapse ; 	
		if `k'==20 { ; 	keep if gbdcode==104 | gbdcode==067 | gbdcode==114 ;                                collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==21 { ; 	keep if gbdcode==000 | gbdcode==104 | gbdcode==060 | gbdcode==111 | gbdcode==148 | gbdcode==038 ;                         
		                foreach var of varlist dtotal-d85 { ; 	
											replace `var'=-`var' if gbdcode==104 | gbdcode==060 | gbdcode==111 | gbdcode==148 | gbdcode==038 ; } ;      collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  
		if `k'==22 { ; 	keep if gbdcode==000 | gbdcode==104 | gbdcode==060 | gbdcode==111 | gbdcode==148 ;                         
		                foreach var of varlist dtotal-d85 { ; 	
											replace `var'=-`var' if gbdcode==104 | gbdcode==060 | gbdcode==111 | gbdcode==148 ; } ;      collapse (sum) dtotal-d85 (mean)total-t85 mtotal-m85 ftotal-f85, by(year code gender) ;  		} ;  

		
		if `j'==0 { ;  	di "Both gender" ;   keep if gender==0 ;  keep dtotal-d85 total-t85 year code ;   	} ; 
		if `j'==1 { ; 	di "Male" ;        keep if gender==1 ;  keep dtotal-d85 mtotal-m85 year code ;   	} ; 
		if `j'==2 { ; 	di "Female" ;      keep if gender==2 ;  keep dtotal-d85 ftotal-f85 year code ;   	} ; 

		ren dtotal d100 ;   foreach i in 0 1 5 10 15 20 25 30 35 40 45 50 55 60 65 70 75 80 85 { ; cap ren m`i' t`i' ; cap ren f`i' t`i' ; } ;  
		cap ren total t100 ;  cap ren ftotal t100 ;  cap ren mtotal t100 ;
		
		gen a =code*10000+year ;   drop if a==. ; 
		reshape long d t, i(a) j(age_group) ; 

		merge m:1 age_group using C:\Dropbox\China_Pollution_Projects\rawfiles\pop_weights_long.dta ; drop _merge ; 
		
		gen dr = 100000*d/t ; 
		if `j'==0 { ; 	gen ajdr = pweight*dr ; } ;   
		if `j'==1 { ; 	gen ajdr = mweight*dr ; } ; 
		if `j'==2 { ; 	gen ajdr = fweight*dr ; } ; 

		gen gender = `j' ;   		 
		gen cause=`k' ;     		 		
		saveold temp`k'_`j'.dta, replace ; 
	} ; 
} ; 

use temp1_0.dta, clear ; append using temp1_1.dta ;  append using temp1_2.dta ;       
forvalues k=2/22 { ;   forvalues j=0/2 { ;  append using temp`k'_`j'.dta ; 	} ;  } ;  

drop a pweight fweight mweight ;  
label define genderlbl 0 "Both" 1 "Male" 2 "Female" ;                                    
label define causelbl 1 "All Diseases" 2 "Lung-related Diseases" 3 "Cadio-related Diseases"  4 "Cardiorespiratory-related Diseases" 5 "Heart Disease" 6 "Cancer" 7 "Stroke" 8 "Unintentional Injury" 9 "Non-communicable lung diseases" 10 "Non-pollution related diseases" 11 "Injury" 12 "Communicable lung diseases" 13 "Lung cancer" ;    
label value gender genderlbl ;    label value cause causelbl ;  
label var cause "Cause of death" ; 
*label var d "Number of death" ;  
*label var t "Population" ; 
label var dr "Age specific death rate per 100k people" ; 
label var ajdr "Age adjusted death rate per 100k people" ; 

order year code gender age_group cause ;
sort year code gender cause age_group ;  

preserve ; 

*** calculate age adjusted death rate and life expectancy at birth ; 

* create age ajusted mortality rate per 100k ; 
bysort year code gender cause: egen a = sum(ajdr) ;  replace ajdr=a if age_group==100 ; 
keep if age_group==100 ; 

ren d death ;  ren t pop ; 
keep year code gender cause death pop dr ajdr ; 
gen b=code*100000+10*year+gender ; 
reshape wide death pop dr ajdr, i(b) j(cause) ; 
drop pop2 pop3 pop4 pop5 pop6 pop7 pop8 pop9 pop10 pop11 pop12 pop13 pop14 pop15 pop16 pop17 pop18 pop19 pop20 pop21 pop22 b ;  
ren pop1 population ; 

saveold MortalityRate_91_00.dta, replace ;      

merge 1:1 year code gender using LifeTable_91_00.dta ;  drop _merge ; 
ren gender sex ; 
ren code dsps90 ;  * for merge with documents ; 
merge m:1 dsps90 using 145DSPS.dta ;  drop _merge ; 
sort dsps90 year sex ;  

saveold LifeTable_91_00.dta, replace ; 

restore ; 

*======================================================================================================================================================;
*** The same as the first half of section 4, but now keep every age group ; 
*** Goal: to see mortality trends for each age group for P&P paper ; 

drop if age_group==100 ; 
ren d death ;  ren t pop ; 
keep year code gender age_group cause death pop dr ;  * no need for ajdr for single age group  ; 
gen b=code*10000000+1000*year+100*gender+age_group ; 
reshape wide death pop dr, i(b) j(cause) ; 
drop pop2 pop3 pop4 pop5 pop6 pop7 pop8 pop9 pop10 pop11 pop12 pop13 pop14 pop15 pop16 pop17 pop18 pop19 pop20 pop21 pop22 b ;  
ren pop1 population ; 

saveold MortalityRate_AllAges_91_00.dta, replace ;      

merge 1:1 year code gender age_group using LifeTable_AllAges_91_00.dta ;  drop _merge ; 
ren code dsps90 ;  * for merge with documents ; 
merge m:1 dsps90 using 145DSPS.dta ;  drop _merge ; 
ren gender sex ; 
sort dsps90 year sex age_group ; 
order overall_sequ dsps90 year sex age_group population ; 

saveold LifeTable_AllAges_91_00.dta, replace ; 

forvalues k=1/22 { ;    forvalues j=0/2 { ;  	erase temp`k'_`j'.dta ; 	cap erase t_`k'_`j'.dta ;  } ; } ; 


  
